@@ -7,9 +7,10 @@
 # i)   dropterm.gamlss()
 # ii)  addterm.gamlss()
 # iii) stepGAIC()
-##################################################################
-##################################################################
-##################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # this refers to how the function historically was developed and 
 # can be ignore now 
 # The approach is as follows
@@ -34,10 +35,10 @@
 #     v) we have to implement stepGAICAll A and B now 
 #            stepGAICAll.Bp is ready 
 # 
-###################################################################
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 dropterm.gamlss <- function (object, 
                      scope, 
                      what = c("mu", "sigma", "nu", "tau"),
@@ -52,8 +53,8 @@ dropterm.gamlss <- function (object,
                        cl = NULL, # An optional parallel or snow cluster for use if parallel = "snow". If not supplied, a cluster on the local machine is created for the duration of the boot call.
                      ...) 
 {
-####################################################################
-####################################################################
+################################################################################
+################################################################################
 drop1.scope<-function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"), 
                        parameter= NULL) 
   {
@@ -64,16 +65,16 @@ drop1.scope<-function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"),
               else attr(terms(terms2, what), "factor")
     factor.scope(attr(terms1, "factor"), list(drop = f2))$drop
   }
-####################################################################
-####################################################################
+################################################################################
+################################################################################
   safe_pchisq <- function (q, df, ...) 
   {
     df[df <= 0] <- NA
     pchisq(q = q, df = df, ...)
   }
-####################################################################
+################################################################################
 #   main functions starts here 
-####################################################################
+################################################################################
   what <- if (!is.null(parameter))  {
     match.arg(parameter, choices=c("mu", "sigma", "nu", "tau"))} else  match.arg(what)
   if (!what %in% object$par) 
@@ -93,8 +94,8 @@ drop1.scope<-function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"),
   ans <- matrix(nrow = ns + 1, ncol = 2, dimnames = list(c("<none>", scope),
             c("df", "AIC")))
   ans[1, ] <- extractAIC(object, scale, k = k,   ...)
-################## PARALLEL ########################################
-################## SET UP PART #####################################
+################## PARALLEL ####################################################
+################## SET UP PART #################################################
 if (missing(parallel)) 
        parallel <- "no"
        parallel <- match.arg(parallel)
@@ -109,8 +110,8 @@ if (missing(parallel))
           ncpus <- 1L
   loadNamespace("parallel")
   }
-################## finish parallel ################################
-################################################################### 
+################## finish parallel #############################################
+################################################################################ 
 #  function for parallel apply
   fn <- function(term)
   {
@@ -135,9 +136,9 @@ if (missing(parallel))
         {gaic}
     }
   }
-####################################################################
-####################################################################
-############  parallel #############################################3
+################################################################################
+################################################################################
+############  parallel #########################################################
 ans[-1,] <- if (ncpus > 1L && (have_mc || have_snow)) 
 {
   if (have_mc) 
@@ -161,7 +162,7 @@ ans[-1,] <- if (ncpus > 1L && (have_mc || have_snow))
     }
     else t(parallel::parSapply(cl, scope, fn))
   }
-} # end parallel #################################################
+} # end parallel ###############################################################
 else t(sapply(scope, fn)) 
   dfs <- ans[1, 1] - ans[, 1]
   dfs[1] <- NA
@@ -188,15 +189,15 @@ class(aod) <- c("anova", "data.frame")
   attr(aod, "heading") <- head
   aod
 }
-###################################################################
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 #  addterm
-###################################################################
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 addterm.gamlss <- function (object, 
                      scope,
                      what = c("mu", "sigma", "nu", "tau"), 
@@ -211,7 +212,7 @@ addterm.gamlss <- function (object,
                        cl = NULL, 
                        ...) 
 {
-###################################################################
+################################################################################
   add.scope <- function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"), parameter= NULL ) 
   {
     what <- if (!is.null(parameter))  {
@@ -221,13 +222,13 @@ addterm.gamlss <- function (object,
     factor.scope(attr(terms1, "factor"), list(add = attr(terms2, 
                                                          "factor")))$add  
   }
-###################################################################
+################################################################################
   safe_pchisq <- function (q, df, ...) 
   {
     df[df <= 0] <- NA
     pchisq(q = q, df = df, ...)
   }
-###################################################################
+################################################################################
   what <- if (!is.null(parameter))  {
     match.arg(parameter, choices=c("mu", "sigma", "nu", "tau"))} else  match.arg(what)
   if (!what %in% object$par) 
@@ -242,8 +243,8 @@ addterm.gamlss <- function (object,
   ans <- matrix(nrow = ns + 1, ncol = 2, dimnames = list(c("<none>", scope), 
                 c("df", "AIC")))
   ans[1, ] <- extractAIC(object, scale, k = k,   ...)
-############## PARALLEL ##########################################
-##################################################################
+############## PARALLEL ########################################################
+################################################################################
   if (missing(parallel)) 
     parallel <- "no"
   parallel <- match.arg(parallel)
@@ -258,8 +259,8 @@ addterm.gamlss <- function (object,
       ncpus <- 1L
     loadNamespace("parallel")
   }
-################# finish parallel ##################################
-####################################################################
+################# finish parallel ##############################################
+################################################################################
 #  function for parallel apply
 fn <- function(term)
 {
@@ -284,9 +285,9 @@ fn <- function(term)
       {gaic}
   }
 }
-###################################################################
-###################################################################
-######### parallel ################################################
+################################################################################
+################################################################################
+######### parallel #############################################################
 ans[-1,] <- if (ncpus > 1L && (have_mc || have_snow)) 
 {
   if (have_mc) 
@@ -310,9 +311,9 @@ ans[-1,] <- if (ncpus > 1L && (have_mc || have_snow))
     }
     else t(parallel::parSapply(cl, scope, fn))
   }
-} # end parallel ###################################################
+} # end parallel ###############################################################
 else t(sapply(scope, fn)) 
-###################################################################
+################################################################################
   dfs <- ans[, 1] - ans[1, 1]
   dfs[1] <- NA
   aod <- data.frame(Df = dfs, AIC = ans[, 2])
@@ -338,15 +339,15 @@ else t(sapply(scope, fn))
   attr(aod, "heading") <- head
   aod
 }
-###################################################################
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # modification of Venable and Ripley stepAIC() function
-###################################################################
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 stepGAIC <-function(object, 
                      scope, 
                  direction = c("both", "backward", "forward"), 
@@ -362,7 +363,7 @@ stepGAIC <-function(object,
                         cl = NULL, 
                      ...)                    
 {
-###################################################################
+################################################################################
 # local functions 
 #  1)    mydevianc()
 #  2)    cut.string()
@@ -370,9 +371,9 @@ stepGAIC <-function(object,
 #  4)    step.results() 
 #  5)    droptermP()
 #  6)    addtermP()
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
 mydeviance <- function(x, ...) 
   {
     dev <- deviance(x)
@@ -380,9 +381,9 @@ mydeviance <- function(x, ...)
       dev
     else extractAIC(x, k = 0)[2]
   }
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
 # 2 
 cut.string <- function(string) 
   {
@@ -390,9 +391,9 @@ cut.string <- function(string)
       string[-1] <- paste("\n", string[-1], sep = "")
     string
   }
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
 # 3 
 re.arrange <- function(keep) 
   {
@@ -403,9 +404,9 @@ re.arrange <- function(keep)
     array(unlist(keep, recursive = FALSE), c(nr, nc), list(namr, 
                                                            namc))
   }
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
 # 4 
 step.results <- function(models, fit, object, usingCp = FALSE) #
   {
@@ -431,9 +432,9 @@ step.results <- function(models, fit, object, usingCp = FALSE) #
     fit$anova <- aod
     fit
   }
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
 # 5
 droptermP <- function (object, 
                        scope, 
@@ -449,7 +450,7 @@ droptermP <- function (object,
                        cl = NULL, # An optional parallel or snow cluster for use if parallel = "snow". If not supplied, a cluster on the local machine is created for the duration of the boot call.
                        ...) 
 {
-###################################################################
+################################################################################
 drop1.scope<-function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"), parameter= NULL) 
     {
       what <- if (!is.null(parameter))  {
@@ -459,15 +460,15 @@ drop1.scope<-function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"), par
                 else attr(terms(terms2, what), "factor")
       factor.scope(attr(terms1, "factor"), list(drop = f2))$drop
     }
-###################################################################
+################################################################################
 safe_pchisq <- function (q, df, ...) 
     {
       df[df <= 0] <- NA
       pchisq(q = q, df = df, ...)
     }
-##################################################################
+################################################################################
 #  droptermP  starts here 
-##################################################################
+################################################################################
     what <- if (!is.null(parameter))  {
 match.arg(parameter, choices=c("mu", "sigma", "nu", "tau"))} else  match.arg(what)
 if (!what %in% object$par) 
@@ -487,7 +488,7 @@ if (missing(scope))
      ans <- matrix(nrow = ns + 1, ncol = 2, dimnames = list(c("<none>", scope),
                                                            c("df", "AIC")))
   ans[1, ] <- extractAIC(object, scale, k = k,   ...)
-##################################################################
+################################################################################
 #  function for parallel apply
 fn <- function(term)
     {
@@ -512,9 +513,9 @@ fn <- function(term)
           {gaic}
       }
     }
-###################################################################
+################################################################################
 # --------  parallel ----------------------------------------------
-################################################################### 
+################################################################################ 
     ans[-1,] <- if (ncpus > 1L && (have_mc || have_snow)) 
     {
       if (have_mc) 
@@ -538,7 +539,7 @@ fn <- function(term)
         }
         else t(parallel::parSapply(cl, scope, fn))
       }
-    }# end parallel ###############################################
+    }# end parallel ############################################################
     else t(sapply(scope, fn)) 
        dfs <- ans[1, 1] - ans[, 1]
     dfs[1] <- NA
@@ -565,9 +566,9 @@ if (test == "Chisq")
     attr(aod, "heading") <- head
     aod
   }
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
 #  6 
 #  addterm
 addtermP<- function (object, 
@@ -584,7 +585,7 @@ addtermP<- function (object,
                      cl = NULL, 
                      ...) 
 {
-####################################################################
+################################################################################
 add.scope <- function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"), parameter= NULL ) 
   {
     what <- if (!is.null(parameter))  {
@@ -594,14 +595,14 @@ add.scope <- function (terms1, terms2, what = c("mu", "sigma", "nu", "tau"), par
     factor.scope(attr(terms1, "factor"), list(add = attr(terms2, 
                                                          "factor")))$add  
   }
-#####################################################################
+################################################################################
 safe_pchisq <- function (q, df, ...) 
   {
     df[df <= 0] <- NA
     pchisq(q = q, df = df, ...)
   }
-#####################################################################
-#####################################################################
+################################################################################
+################################################################################
 # starts here
     what <- if (!is.null(parameter))  {
 match.arg(parameter, choices=c("mu", "sigma", "nu", "tau"))} else  match.arg(what)  
@@ -618,7 +619,7 @@ if (!length(scope))
                                                          c("df", "AIC")))
 ans[1, ] <- extractAIC(object, scale, k = k,   ...)
 #  function for parallel apply
-###################################################################
+################################################################################
 fn <- function(term)
   {
     if (trace) 
@@ -642,8 +643,8 @@ fn <- function(term)
         {gaic}
     }
   }
-###################################################################
-##########  parallel ############################################## 
+################################################################################
+##########  parallel ########################################################### 
 ans[-1,] <- if (ncpus > 1L && (have_mc || have_snow)) 
   {
     if (have_mc) 
@@ -667,9 +668,9 @@ ans[-1,] <- if (ncpus > 1L && (have_mc || have_snow))
       }
       else t(parallel::parSapply(cl, scope, fn))
     }
-  } # end parallel ################################################
+  } # end parallel #############################################################
   else t(sapply(scope, fn)) 
-###################################################################
+################################################################################
      dfs <- ans[, 1] - ans[1, 1]
   dfs[1] <- NA
      aod <- data.frame(Df = dfs, AIC = ans[, 2])
@@ -694,12 +695,12 @@ if (test == "Chisq")
   attr(aod, "heading") <- head
   aod
 }
-###################################################################
-###################################################################
+################################################################################
+################################################################################
 # main stepGAIC function starts here
-###################################################################
-################ PARALLEL #########################################
-################ SET UP PART ######################################
+################################################################################
+################ PARALLEL ######################################################
+################ SET UP PART ###################################################
 if (missing(parallel)) 
     parallel <- "no"
     parallel <- match.arg(parallel)
@@ -721,8 +722,8 @@ if (have_snow)
     parallel::clusterSetRNGStream(cl)
       on.exit(parallel::stopCluster(cl))
 }         
-################# finish parallel ##################################
-#################################################################### 
+################# finish parallel ##############################################
+################################################################################ 
       what <- if (!is.null(parameter))  {
     match.arg(parameter, choices=c("mu", "sigma", "nu", "tau"))} else  match.arg(what)
      Terms <- terms(object, what)
@@ -786,9 +787,11 @@ if (is.na(bAIC))
 nm <- 1
 Terms <- terms(fit, what)
 if (trace)
+{
   cat("Distribution parameter: ", what, "\n") 
-cat("Start:  AIC=", format(round(bAIC, 2)), "\n", cut.string(deparse(as.vector(formula(fit, what=what)))), 
-    "\n\n")
+  cat("Start:  AIC=", format(round(bAIC, 2)), "\n", cut.string(deparse(as.vector(formula(fit, what=what)))), 
+      "\n\n")  
+}  
 models[[nm]] <- list(deviance = mydeviance(fit), df.resid = n - 
                        edf, change = "", AIC = bAIC)
 if (!is.null(keep)) 
@@ -886,7 +889,7 @@ if (!is.null(keep))
   fit$keep <- re.arrange(keep.list[seq(nm)])
 step.results(models = models[seq(nm)], fit, object, usingCp)
 }
-###################################################################
-###################################################################
-###################################################################
-###################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
